@@ -2,18 +2,17 @@
 
 # distribution.py
 # definitions of spatial distribution characters
-
 import math
+import os
+import warnings
 
-import geopandas as gpd
 import networkx as nx
 import numpy as np
 import pandas as pd
 import shapely
-from packaging.version import Version
 from tqdm.auto import tqdm  # progress bar
 
-from .utils import _azimuth
+from .utils import _azimuth, deprecated, removed
 
 __all__ = [
     "Orientation",
@@ -29,9 +28,8 @@ __all__ = [
     "Neighbors",
 ]
 
-GPD_GE_013 = Version(gpd.__version__) >= Version("0.13.0")
-
 
+@deprecated("orientation")
 class Orientation:
     """
     Calculate the orientation of object. The deviation of orientation from cardinal
@@ -136,12 +134,24 @@ class SharedWalls:
     """
 
     def __init__(self, gdf):
+        if os.getenv("ALLOW_LEGACY_MOMEPY", "False").lower() not in (
+            "true",
+            "1",
+            "yes",
+        ):
+            warnings.warn(
+                "Class based API like `momepy.SharedWalls` or `momepy.SharedWallsRatio`"
+                " is deprecated. Replace it with `momepy.shared_walls` or explicitly "
+                "computing `momepy.shared_walls / gdf.length` respectively to use "
+                "functional API instead or pin momepy version <1.0. Class-based API "
+                "will be removed in 1.0. ",
+                # "See details at https://docs.momepy.org/en/stable/migration.html",
+                FutureWarning,
+                stacklevel=2,
+            )
         self.gdf = gdf
 
-        if GPD_GE_013:
-            inp, res = gdf.sindex.query(gdf.geometry, predicate="intersects")
-        else:
-            inp, res = gdf.sindex.query_bulk(gdf.geometry, predicate="intersects")
+        inp, res = gdf.sindex.query(gdf.geometry, predicate="intersects")
         left = gdf.geometry.take(inp).reset_index(drop=True)
         right = gdf.geometry.take(res).reset_index(drop=True)
         intersections = left.intersection(right).length
@@ -206,6 +216,7 @@ class SharedWallsRatio(SharedWalls):
         self.series = self.series / self.perimeters
 
 
+@deprecated("street_alignment")
 class StreetAlignment:
     """
     Calculate the difference between street orientation and orientation of
@@ -321,6 +332,7 @@ class StreetAlignment:
         self.series.index = left.index
 
 
+@deprecated("cell_alignment")
 class CellAlignment:
     """
     Calculate the difference between cell orientation and the orientation of object.
@@ -417,8 +429,8 @@ class CellAlignment:
         self.series.index = left.index
 
 
+@deprecated("alignment")
 class Alignment:
-
     """
     Calculate the mean deviation of solar orientation of objects on adjacent cells
     from an object.
@@ -497,6 +509,7 @@ class Alignment:
         self.series = pd.Series(results_list, index=gdf.index)
 
 
+@deprecated("neighbor_distance")
 class NeighborDistance:
     """
     Calculate the mean distance to adjacent buildings (based on ``spatial_weights``).
@@ -565,6 +578,7 @@ class NeighborDistance:
         self.series = pd.Series(results_list, index=gdf.index)
 
 
+@deprecated("mean_interbuilding_distance")
 class MeanInterbuildingDistance:
     """
     Calculate the mean interbuilding distance. Interbuilding distances are
@@ -660,6 +674,7 @@ class MeanInterbuildingDistance:
         self.series = pd.Series(results_list, index=gdf.index)
 
 
+@removed("mean_deviation")
 class NeighboringStreetOrientationDeviation:
     """
     Calculate the mean deviation of solar orientation of adjacent streets. The
@@ -696,10 +711,7 @@ class NeighboringStreetOrientationDeviation:
         self.gdf = gdf
         self.orientation = gdf.geometry.apply(self._orient)
 
-        if GPD_GE_013:
-            inp, res = gdf.sindex.query(gdf.geometry, predicate="intersects")
-        else:
-            inp, res = gdf.sindex.query_bulk(gdf.geometry, predicate="intersects")
+        inp, res = gdf.sindex.query(gdf.geometry, predicate="intersects")
         itself = inp == res
         inp = inp[~itself]
         res = res[~itself]
@@ -737,6 +749,7 @@ class NeighboringStreetOrientationDeviation:
         return az
 
 
+@deprecated("building_adjacency")
 class BuildingAdjacency:
     """
     Calculate the level of building adjacency. Building adjacency reflects how much
@@ -832,6 +845,7 @@ class BuildingAdjacency:
         self.series = pd.Series(results_list, index=gdf.index)
 
 
+@deprecated("neighbors")
 class Neighbors:
     """
     Calculate the number of neighbours captured by ``spatial_weights``. If
